@@ -1,6 +1,10 @@
 import os
 ROOT_DIR = os.path.dirname(os.path.abspath(__file__))
 
+__project__ = "SolarY"
+__author__ = "Dr.-Ing. Thomas Albin"
+__version__ = "0.5.2"
+
 from . import _config
 
 from . import tests
